@@ -10,7 +10,6 @@ from .version import __version__  # noqa
 
 
 from .fieldwidgets import (
-    MISSING,
     BoolCheckBox,
     EmptyIntValidator,
     IntLineEdit,
@@ -25,6 +24,10 @@ from .datawidget import (
     type2Widget,
     dataclass2Widget,
 )
+from .multitype import (
+    DataclassStackedWidget,
+    DataclassTabWidget,
+)
 from .delegate import (
     DataclassDelegate,
     DataclassMapper,
@@ -33,7 +36,6 @@ from .delegate import (
 
 __all__ = [
     "BoolCheckBox",
-    "MISSING",
     "EmptyIntValidator",
     "IntLineEdit",
     "EmptyFloatValidator",
@@ -44,6 +46,8 @@ __all__ = [
     "DataWidget",
     "type2Widget",
     "dataclass2Widget",
+    "DataclassStackedWidget",
+    "DataclassTabWidget",
     "DataclassDelegate",
     "DataclassMapper",
 ]
